==> pandas-profiling-3.5.0.tar.gz: pandas-profiling-3.5.0/src/pandas_profiling/report/presentation/flavours/widget/__init__.py <==
from pandas_profiling.report.presentation.flavours.widget.alerts import WidgetAlerts
from pandas_profiling.report.presentation.flavours.widget.collapse import WidgetCollapse
from pandas_profiling.report.presentation.flavours.widget.container import (
    WidgetContainer,
)
from pandas_profiling.report.presentation.flavours.widget.dropdown import WidgetDropdown
from pandas_profiling.report.presentation.flavours.widget.duplicate import (
    WidgetDuplicate,
)
from pandas_profiling.report.presentation.flavours.widget.frequency_table import (
    WidgetFrequencyTable,
)
from pandas_profiling.report.presentation.flavours.widget.frequency_table_small import (
    WidgetFrequencyTableSmall,
)
from pandas_profiling.report.presentation.flavours.widget.html import WidgetHTML
from pandas_profiling.report.presentation.flavours.widget.image import WidgetImage
from pandas_profiling.report.presentation.flavours.widget.root import WidgetRoot
from pandas_profiling.report.presentation.flavours.widget.sample import WidgetSample
from pandas_profiling.report.presentation.flavours.widget.table import WidgetTable
from pandas_profiling.report.presentation.flavours.widget.toggle_button import (
    WidgetToggleButton,
)
from pandas_profiling.report.presentation.flavours.widget.variable import WidgetVariable
from pandas_profiling.report.presentation.flavours.widget.variable_info import (
    WidgetVariableInfo,
)

__all__ = [
    "WidgetCollapse",
    "WidgetContainer",
    "WidgetDuplicate",
    "WidgetDropdown",
    "WidgetFrequencyTable",
    "WidgetFrequencyTableSmall",
    "WidgetHTML",
    "WidgetImage",
    "WidgetRoot",
    "WidgetSample",
    "WidgetTable",
    "WidgetToggleButton",
    "WidgetVariable",
    "WidgetVariableInfo",
    "WidgetAlerts",
]

==> pandas-profiling-3.6.0.tar.gz: pandas-profiling-3.6.0/src/pandas_profiling/report/presentation/flavours/widget/__init__.py <==
from pandas_profiling.report.presentation.flavours.widget.alerts import WidgetAlerts
from pandas_profiling.report.presentation.flavours.widget.collapse import WidgetCollapse
from pandas_profiling.report.presentation.flavours.widget.container import (
    WidgetContainer,
)
from pandas_profiling.report.presentation.flavours.widget.correlation_table import (
    WidgetCorrelationTable,
)
from pandas_profiling.report.presentation.flavours.widget.dropdown import WidgetDropdown
from pandas_profiling.report.presentation.flavours.widget.duplicate import (
    WidgetDuplicate,
)
from pandas_profiling.report.presentation.flavours.widget.frequency_table import (
    WidgetFrequencyTable,
)
from pandas_profiling.report.presentation.flavours.widget.frequency_table_small import (
    WidgetFrequencyTableSmall,
)
from pandas_profiling.report.presentation.flavours.widget.html import WidgetHTML
from pandas_profiling.report.presentation.flavours.widget.image import WidgetImage
from pandas_profiling.report.presentation.flavours.widget.root import WidgetRoot
from pandas_profiling.report.presentation.flavours.widget.sample import WidgetSample
from pandas_profiling.report.presentation.flavours.widget.table import WidgetTable
from pandas_profiling.report.presentation.flavours.widget.toggle_button import (
    WidgetToggleButton,
)
from pandas_profiling.report.presentation.flavours.widget.variable import WidgetVariable
from pandas_profiling.report.presentation.flavours.widget.variable_info import (
    WidgetVariableInfo,
)

__all__ = [
    "WidgetCollapse",
    "WidgetContainer",
    "WidgetDuplicate",
    "WidgetDropdown",
    "WidgetFrequencyTable",
    "WidgetFrequencyTableSmall",
    "WidgetHTML",
    "WidgetImage",
    "WidgetRoot",
    "WidgetSample",
    "WidgetTable",
    "WidgetToggleButton",
    "WidgetVariable",
    "WidgetVariableInfo",
    "WidgetAlerts",
    "WidgetCorrelationTable",
]
